@@ -1,8 +1,8 @@
 /* info.c -- Display nodes of Info files in multiple windows.
-   $Id: info.c,v 1.20 2007/09/01 00:05:23 karl Exp $
+   $Id: info.c,v 1.28 2008/02/22 19:18:25 karl Exp $
 
    Copyright (C) 1993, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003,
-   2004, 2005, 2007 Free Software Foundation, Inc.
+   2004, 2005, 2007, 2008 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-   Written by Brian Fox (bfox@ai.mit.edu). */
+   Originally written by Brian Fox (bfox@ai.mit.edu). */
 
 #include "info.h"
 #include "indices.h"
@@ -94,12 +94,11 @@ int speech_friendly = 0;
 /* Structure describing the options that Info accepts.  We pass this structure
    to getopt_long ().  If you add or otherwise change this structure, you must
    also change the string which follows it. */
-#define APROPOS_OPTION 1
 #define DRIBBLE_OPTION 2
 #define RESTORE_OPTION 3
 #define IDXSRCH_OPTION 4
 static struct option long_options[] = {
-  { "apropos", 1, 0, APROPOS_OPTION },
+  { "apropos", 1, 0, 'k' },
   { "directory", 1, 0, 'd' },
   { "dribble", 1, 0, DRIBBLE_OPTION },
   { "file", 1, 0, 'f' },
@@ -125,9 +124,9 @@ static struct option long_options[] = {
 
 /* String describing the shorthand versions of the long options found above. */
 #ifdef __MSDOS__
-static char *short_options = "d:n:f:ho:ORswb";
+static char *short_options = "k:d:n:f:ho:ORswb";
 #else
-static char *short_options = "d:n:f:ho:ORws";
+static char *short_options = "k:d:n:f:ho:ORws";
 #endif
 
 /* When non-zero, the Info window system has been initialized. */
@@ -145,7 +144,7 @@ static void init_messages (void);
 /* **************************************************************** */
 
 int
-main (int argc, char **argv)
+main (int argc, char *argv[])
 {
   int getopt_long_index;        /* Index returned by getopt_long (). */
   NODE *initial_node;           /* First node loaded by Info. */
@@ -153,19 +152,6 @@ main (int argc, char **argv)
 #ifdef HAVE_SETLOCALE
   /* Set locale via LC_ALL.  */
   setlocale (LC_ALL, "");
-
-  /* But don't use translated messages in the case when
-     string width and length can differ */
-  if (MB_CUR_MAX > 1)
-    {
-      setenv("LANGUAGE", "C", 1);
-      setenv("LANG", "C", 1);
-#ifdef LC_MESSAGES
-      setlocale (LC_MESSAGES, "C");
-#endif
-      setenv("LC_CTYPE", "C", 1);
-      setenv("LC_ALL", "C", 1);
-    }
 #endif /* HAVE_SETLOCALE */
 
 #ifdef ENABLE_NLS
@@ -259,7 +245,7 @@ main (int argc, char **argv)
 #endif /* __MSDOS__ */
 
           /* User has specified a string to search all indices for. */
-        case APROPOS_OPTION:
+        case 'k':
           apropos_p = 1;
           maybe_free (apropos_search_string);
           apropos_search_string = xstrdup (optarg);
@@ -307,7 +293,7 @@ main (int argc, char **argv)
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n"),
-	      "2007");
+	      "2008");
       xexit (0);
     }
 
@@ -411,6 +397,12 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
     const char *errstr;
     char *errarg1, *errarg2;
 
+   /* If they say info -O info, we want to show them the invocation node
+      for standalone info; there's nothing useful in info.texi.  */
+   if (goto_invocation_p && argv[optind]
+       && mbscasecmp (argv[optind], "info") == 0)
+     argv[optind] = "info-stnd";
+
     NODE *new_initial_node = info_follow_menus (initial_node, argv + optind,
         &errstr, &errarg1, &errarg2);
 
@@ -568,7 +560,12 @@ info_error (char *format, void *arg1, void *arg2)
   if (!info_windows_initialized_p || display_inhibited)
     {
       fprintf (stderr, "%s: ", program_name);
-      fprintf (stderr, format, arg1, arg2);
+      if (arg1)
+        fprintf (stderr, format, arg1, arg2);
+      else
+        /* If we're passed a string, just print it.  Otherwise a % in a
+           filename gets treated as a format specifier.  */
+        fputs (format, stderr);
       fprintf (stderr, "\n");
       fflush (stderr);
     }
@@ -582,9 +579,7 @@ info_error (char *format, void *arg1, void *arg2)
         }
       else
         {
-          NODE *temp;
-
-          temp = build_message_node (format, arg1, arg2);
+          NODE *temp = build_message_node (format, arg1, arg2);
           if (info_error_rings_bell_p)
             terminal_ring_bell ();
           inform_in_echo_area (temp->contents);
@@ -599,52 +594,57 @@ info_error (char *format, void *arg1, void *arg2)
 static void
 info_short_help (void)
 {
-#ifdef __MSDOS__
-  static const char speech_friendly_string[] = N_("\
-  -b, --speech-friendly        be friendly to speech synthesizers.\n");
-#else
-  static const char speech_friendly_string[] = "";
-#endif
-
-
   printf (_("\
 Usage: %s [OPTION]... [MENU-ITEM...]\n\
 \n\
-Read documentation in Info format.\n\
-\n\
+Read documentation in Info format.\n"), program_name);
+  puts ("");
+
+  puts (_("\
 Options:\n\
-      --apropos=STRING         look up STRING in all indices of all manuals.\n\
+  -k, --apropos=STRING         look up STRING in all indices of all manuals.\n\
   -d, --directory=DIR          add DIR to INFOPATH.\n\
       --dribble=FILENAME       remember user keystrokes in FILENAME.\n\
-  -f, --file=FILENAME          specify Info file to visit.\n\
+  -f, --file=FILENAME          specify Info file to visit."));
+
+  puts (_("\
   -h, --help                   display this help and exit.\n\
       --index-search=STRING    go to node pointed by index entry STRING.\n\
   -n, --node=NODENAME          specify nodes in first visited Info file.\n\
-  -o, --output=FILENAME        output selected nodes to FILENAME.\n\
+  -o, --output=FILENAME        output selected nodes to FILENAME."));
+
+  puts (_("\
   -R, --raw-escapes            output \"raw\" ANSI escapes (default).\n\
       --no-raw-escapes         output escapes as literal text.\n\
       --restore=FILENAME       read initial keystrokes from FILENAME.\n\
-  -O, --show-options, --usage  go to command-line options node.\n%s\
+  -O, --show-options, --usage  go to command-line options node."));
+
+#ifdef __MSDOS__
+  puts (_("\
+  -b, --speech-friendly        be friendly to speech synthesizers."));
+#endif
+
+  puts (_("\
       --subnodes               recursively output menu items.\n\
-  -w, --where, --location      print physical location of Info file.\n\
       --vi-keys                use vi-like and less-like key bindings.\n\
       --version                display version information and exit.\n\
-\n\
+  -w, --where, --location      print physical location of Info file."));
+
+  puts (_("\n\
 The first non-option argument, if present, is the menu entry to start from;\n\
 it is searched for in all `dir' files along INFOPATH.\n\
 If it is not present, info merges all `dir' files and shows the result.\n\
 Any remaining arguments are treated as the names of menu\n\
-items relative to the initial node visited.\n\
-\n\
+items relative to the initial node visited."));
+
+  puts (_("\n\
 Examples:\n\
   info                       show top-level dir menu\n\
   info emacs                 start at emacs node from top-level dir\n\
   info emacs buffers         start at buffers node within emacs manual\n\
   info --show-options emacs  start at node with emacs' command line options\n\
   info --subnodes -o out.txt emacs  dump entire manual to out.txt\n\
-  info -f ./foo.info         show file ./foo.info, not searching dir\n\
-"),
-  program_name, speech_friendly_string);
+  info -f ./foo.info         show file ./foo.info, not searching dir"));
 
   puts (_("\n\
 Email bug reports to bug-texinfo@gnu.org,\n\
