@@ -1,8 +1,8 @@
 /* infodoc.c -- functions which build documentation nodes.
-   $Id: infodoc.c,v 1.14 2007/08/26 12:58:56 karl Exp $
+   $Id: infodoc.c,v 1.18 2008/02/21 23:36:16 karl Exp $
 
-   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2006, 2007
-   Free Software Foundation, Inc.
+   Copyright (C) 1993, 1997, 1998, 1999, 2001, 2002, 2003, 2004, 2006,
+   2007, 2008 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -51,43 +51,40 @@ static char *info_internal_help_text[] = {
   "\n",
   N_("Selecting other nodes:\n\
 ----------------------\n"),
-  N_("\\%-10[next-node]  Move to the \"next\" node of this node.\n"),
-  N_("\\%-10[prev-node]  Move to the \"previous\" node of this node.\n"),
-  N_("\\%-10[up-node]  Move \"up\" from this node.\n"),
-  N_("\\%-10[menu-item]  Pick menu item specified by name.\n\
-              Picking a menu item causes another node to be selected.\n"),
-  N_("\\%-10[xref-item]  Follow a cross reference.  Reads name of reference.\n"),
-  N_("\\%-10[history-node]  Move to the last node seen in this window.\n"),
+  N_("\\%-10[global-next-node]  Move to the next node in the document.\n"),
+  N_("\\%-10[global-prev-node]  Move to the previous node in the document.\n"),
   N_("\\%-10[move-to-next-xref]  Skip to next hypertext link [*].\n"),
-  N_("\\%-10[move-to-prev-xref]  Skip to previous hypertext link [*].\n"),
   N_("\\%-10[select-reference-this-line]  Follow the hypertext link under cursor.\n"),
+  N_("\\%-10[up-node]  Move \"up\" from this node.\n"),
+  N_("\\%-10[history-node]  Move to the last node seen in this window.\n"),
   N_("\\%-10[dir-node]  Move to the `directory' node.  Equivalent to `\\[goto-node] (DIR)'.\n"),
   N_("\\%-10[top-node]  Move to the Top node.  Equivalent to `\\[goto-node] Top'.\n"),
   "\n",
-  N_("[*]    Command acts within this node or the entire document, depending on\n"
-     "the value of cursor-movement-scrolls variable\n"),
-  "\n",
   N_("Moving within a node:\n\
 ---------------------\n"),
   N_("\\%-10[beginning-of-node]  Go to the beginning of this node.\n"),
   N_("\\%-10[end-of-node]  Go to the end of this node.\n"),
-  N_("\\%-10[next-line]  Scroll forward 1 line.\n"),
-  N_("\\%-10[prev-line]  Scroll backward 1 line.\n"),
-  N_("\\%-10[scroll-forward]  Scroll forward a page.\n"),
-  N_("\\%-10[scroll-backward]  Scroll backward a page.\n"),
+  N_("\\%-10[next-line]  Scroll forward one line.\n"),
+  N_("\\%-10[prev-line]  Scroll backward one line.\n"),
+  N_("\\%-10[scroll-forward-page-only]  Scroll forward within this node.\n"),
+  N_("\\%-10[scroll-backward-page-only]  Scroll backward within this node.\n"),
   "\n",
   N_("Other commands:\n\
 ---------------\n"),
-  N_("1...9       Pick first...ninth item in this node's menu.\n"),
-  N_("\\%-10[last-menu-item]  Pick last item in this node's menu.\n"),
-  N_("\\%-10[index-search]  Search for a specified string in the index entries of this Info\n\
-              file, and select the node referenced by the first entry found.\n"),
-  N_("\\%-10[goto-node]  Move to node specified by name.\n\
-              You may include a filename as well, as in (FILENAME)NODENAME.\n"),
   N_("\\%-10[search]  Search forward for a specified string\n\
               and select the node in which the next occurrence is found.\n"),
   N_("\\%-10[search-backward]  Search backward for a specified string\n\
               and select the node in which the previous occurrence is found.\n"),
+  N_("1...9       Pick first...ninth item in this node's menu.\n"),
+  N_("\\%-10[last-menu-item]  Pick last item in this node's menu.\n"),
+  N_("\\%-10[menu-item]  Pick menu item specified by name.\n"),
+  N_("\\%-10[index-search]  Search for a specified string in the index entries of this Info\n\
+              file, and select the node referenced by the first entry found.\n"),
+  N_("\\%-10[xref-item]  Follow a cross reference.  Reads name of reference.\n"),
+  N_("\\%-10[goto-node]  Move to node specified by name.\n\
+              You may include a filename as well, as in (FILENAME)NODENAME.\n"),
+  N_("\\%-10[next-node]  Move to the next node of current section.\n"),
+  N_("\\%-10[prev-node]  Move to the previous node of current section.\n"),
   NULL
 };
 
@@ -106,8 +103,8 @@ static char *info_internal_help_text[] = {
   N_("  %-10s  Move to the `next' node of this node.\n"),
   N_("  %-10s  Move to the `previous' node of this node.\n"),
   N_("  %-10s  Move `up' from this node.\n"),
-  N_("  %-10s  Pick menu item specified by name.\n"),
-  N_("              Picking a menu item causes another node to be selected.\n"),
+  N_("  %-10s  Pick menu item specified by name.\n\
+              Picking a menu item causes another node to be selected.\n"),
   N_("  %-10s  Follow a cross reference.  Reads name of reference.\n"),
   N_("  %-10s  Move to the last node seen in this window.\n"),
   N_("  %-10s  Skip to next hypertext link within this node.\n"),
@@ -126,18 +123,18 @@ static char *info_internal_help_text[] = {
   "\n",
   N_("Other commands:\n\
 ---------------\n"),
-  N_("  %-10s  Pick first ... ninth item in node's menu.\n"),
+  N_("  %-10s  Pick first...ninth item in node's menu.\n"),
   N_("  %-10s  Pick last item in node's menu.\n"),
-  /* This string and the one below are one sentence, so they need to be
+  /* The next four strings are each a unity, so they each need to be
      kept as one string for the translators.  */
   N_("  %-10s  Search for a specified string in the index entries of this Info\n\
               file, and select the node referenced by the first entry found.\n"),
-  N_("  %-10s  Move to node specified by name.\n"),
-  N_("              You may include a filename as well, as in (FILENAME)NODENAME.\n"),
+  N_("  %-10s  Move to node specified by name.\n\
+              You may include a filename as well, as in (FILENAME)NODENAME.\n"),
   N_("  %-10s  Search forward for a specified string,\n\
               and select the node in which the next occurrence is found.\n"),
-  N_("  %-10s  Search backward for a specified string\n"),
-  N_("              and select the node in which the next occurrence is found.\n"),
+  N_("  %-10s  Search backward for a specified string,\n\
+              and select the node in which the next occurrence is found.\n"),
   NULL
 };
 
@@ -517,7 +514,7 @@ DECLARE_INFO_COMMAND (info_get_info_help_node, _("Visit Info node `(info)Help'")
     for (win = windows; win; win = win->next)
       {
         if (win->node && win->node->filename &&
-            (strcasecmp
+            (mbscasecmp
              (filename_non_directory (win->node->filename), "info") == 0) &&
             ((strcmp (win->node->nodename, "Help") == 0) ||
              (strcmp (win->node->nodename, "Help-Small-Screen") == 0)))
