@@ -1,8 +1,8 @@
 /* cmds.c -- Texinfo commands.
-   $Id: cmds.c,v 1.75 2007/07/15 11:51:12 olegkat Exp $
+   $Id: cmds.c,v 1.82 2008/02/17 19:07:58 karl Exp $
 
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
-   Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+   2007, 2008 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include "files.h"
 #include "footnote.h"
 #include "html.h"
+#include "index.h"
 #include "insertion.h"
 #include "lang.h"
 #include "macro.h"
@@ -99,6 +100,7 @@ COMMAND command_table[] = {
   { "appendixsec", cm_appendixsec, NO_BRACE_ARGS },
   { "appendixsubsec", cm_appendixsubsec, NO_BRACE_ARGS },
   { "appendixsubsubsec", cm_appendixsubsubsec, NO_BRACE_ARGS },
+  { "arrow", cm_arrow, BRACE_ARGS },
   { "asis", cm_no_op, BRACE_ARGS },
   { "author", cm_author, NO_BRACE_ARGS },
   { "b", cm_b, BRACE_ARGS },
@@ -114,6 +116,9 @@ COMMAND command_table[] = {
   { "cindex", cm_cindex, NO_BRACE_ARGS },
   { "cite", cm_cite, BRACE_ARGS },
   { "clear", cm_clear, NO_BRACE_ARGS },
+  { "click", cm_click, BRACE_ARGS },
+  { "clicksequence", cm_clicksequence, BRACE_ARGS },
+  { "clickstyle", cm_clickstyle, NO_BRACE_ARGS },
   { "code", cm_code, BRACE_ARGS },
   { "comma", cm_comma, BRACE_ARGS },
   { "command", cm_code, BRACE_ARGS },
@@ -1001,8 +1006,6 @@ cm_code (int arg)
     }
   else
     {
-      extern int printing_index;
-
       if (!printing_index)
         {
           if (arg == START)
@@ -1286,7 +1289,9 @@ cm_cite (int arg, int position)
     {
       if (arg == START)
         add_char ('`');
-      else
+      else if (!looking_at ("}'"))
+        /* In the simple case of, e.g.,  ... @cite{Foo}'s ...
+           don't output a double ''.  */
         add_char ('\'');
     }
 }
@@ -1305,7 +1310,6 @@ cm_i (int arg)
 {
   /* Make use of <lineannotation> of Docbook, if we are
      inside an @example or similar.  */
-  extern int printing_index;
   if (docbook && !filling_enabled && !printing_index)
     xml_insert_element (LINEANNOTATION, arg);
   else if (xml)
@@ -1321,7 +1325,6 @@ cm_slanted (int arg)
 {
   /* Make use of <lineannotation> of Docbook, if we are
      inside an @example or similar.  */
-  extern int printing_index;
   if (docbook && !filling_enabled && !printing_index)
     xml_insert_element (LINEANNOTATION, arg);
   else if (xml)
@@ -1336,7 +1339,6 @@ void
 cm_b (int arg)
 {
   /* See cm_i comments.  */
-  extern int printing_index;
   if (docbook && !filling_enabled && !printing_index)
     xml_insert_element (LINEANNOTATION, arg);
   else if (docbook && arg == START)
@@ -1353,7 +1355,6 @@ void
 cm_r (int arg)
 {
   /* See cm_i comments.  */
-  extern int printing_index;
   if (docbook && !filling_enabled && !printing_index)
     xml_insert_element (LINEANNOTATION, arg);
   else if (xml)
@@ -1368,7 +1369,6 @@ void
 cm_sansserif (int arg)
 {
   /* See cm_i comments.  */
-  extern int printing_index;
   if (docbook && !filling_enabled && !printing_index)
     xml_insert_element (LINEANNOTATION, arg);
   else if (xml)
@@ -1537,7 +1537,6 @@ cm_settitle (void)
 {
   if (xml)
     {
-      xml_begin_document (current_output_filename);
       xml_insert_element (SETTITLE, START);
       xml_in_book_title = 1;
       get_rest_of_line (0, &title);
@@ -1637,10 +1636,14 @@ cm_dircategory (void)
 
       if (!no_headers && !html)
         {
+          /* use add_* instead of insert_* because otherwise the
+             file header ("This is ...") will end up inside the
+             dir section markers.  */
           kill_self_indent (-1); /* make sure there's no indentation */
-          insert_string ("INFO-DIR-SECTION ");
-          insert_string (line);
-          insert ('\n');
+          cm_noindent (); /* make sure again */
+          add_word ("INFO-DIR-SECTION ");
+          add_word (line);
+          close_single_paragraph ();  /* newline */
         }
 
       free (line);
@@ -1717,11 +1720,56 @@ cm_center (void)
       filling_enabled = save_filling_enabled;
       indented_fill = save_indented_fill;
       close_single_paragraph ();
-      if (looking_at("\n"))
+      if (looking_at ("\n"))
         insert ('\n');
     }
 }
 
+
+/* Define what @click{} does.  */
+static char *click_command = "@arrow";
+
+void
+cm_clickstyle (void)
+{
+  click_command = get_item_function ();
+
+  if (looking_at ("\n"))
+    {
+      input_text_offset++;
+      line_number++;
+    }
+}
+
+/* @clicksequence{File @click{} Open} */
+void
+cm_clicksequence (int arg)
+{
+  if (xml)
+    xml_insert_element (CLICKSEQUENCE, arg);
+}
+
+void
+cm_click (int arg)
+{
+  if (xml)
+    xml_insert_element (CLICK, arg);
+  else if (arg == END)
+    execute_string ("%s{}", click_command);
+}
+
+
+/* Generic right arrow, default clickstyle.  */
+void
+cm_arrow (int arg)
+{
+  if (arg == END)
+    if (html || xml)
+      xml_insert_entity ("rarr");
+    else
+      add_word ("->");
+}
+
 /* Show what an expression returns. */
 void
 cm_result (int arg)
@@ -1849,7 +1897,13 @@ handle_include (int verbatim_include)
   get_rest_of_line (0, &arg);
   /* We really only want to expand @value, but it's easier to just do
      everything.  TeX will only work with @value.  */
-  filename = text_expansion (arg);
+  {
+    int save_in_fixed_width_font = in_fixed_width_font;
+    in_fixed_width_font = 1;  /* do not change -- to -, etc.  */
+    filename = text_expansion (arg);
+    in_fixed_width_font = save_in_fixed_width_font;    
+  }
+
   free (arg);
   
   if (macro_expansion_output_stream && !executing_string)
